@echo off
rem *******************************************************************************
rem Licensed Materials - Property of IBM
rem (c) Copyright IBM Corporation 2008, 2014. All Rights Reserved.
rem 
rem Note to U.S. Government Users Restricted Rights:  
rem Use, duplication or disclosure restricted by GSA ADP Schedule 
rem Contract with IBM Corp. 
rem *******************************************************************************

set START_DIR=%~dp0

rem The following four environment variables are used to point to the
rem appropriate JDBC jar file supplied by the database vendor.  For Oracle and
rem SQL Server, the environment variable should point to the driver file itself;
rem for db2i and db2z, the variable should point to the directory that contains
rem the multiple necessary jdbc driver files required on those platforms (for example, 
rem c:\Program Files\IBM\SQLLIB\java\). For DB2, the use of DB2_ABSPATH is optional; 
rem if not set, the default driver installed with the server will be used.

rem Users should set these variables; if they are set, the script will respect
rem their value.  If they are unset, we try locating the driver files in a
rem directory under <JazzInstallDir>/server.  (For example, the default location
rem for the Oracle JDBC driver is under
rem <JazzInstallDir>/server/oracle/ojdbc6.jar).

rem Do not use double quotes when you define your environment variable.  If
rem you're setting it from the command line, do:
rem set ORACLE_JDBC_DRIVER_FILE=c:\path name\ojdbc6.jar
rem not:
rem set ORACLE_JDBC_DRIVER_FILE="c:\path name\ojdbc6.jar"

if NOT "%ORACLE_JDBC_DRIVER_FILE%"=="" goto :after_oracle
set ORACLE_JDBC_DRIVER_FILE=%START_DIR%\oracle\ojdbc6.jar
:after_oracle

if NOT "%SQLSERVER_JDBC_DRIVER_FILE%"=="" goto :after_sqlserver
set SQLSERVER_JDBC_DRIVER_FILE=%START_DIR%\sqlserver\sqljdbc4.jar
:after_sqlserver

if "%DB2I_ABSPATH%"=="" goto :default_db2i
set DB2I_JDBC=%DB2I_ABSPATH%
goto :after_db2i
:default_db2i
set DB2I_JDBC=%START_DIR%\db2i
:after_db2i

if "%DB2Z_ABSPATH%"=="" goto :default_db2z
set DB2Z_JDBC=%DB2Z_ABSPATH%
goto :after_db2z
:default_db2z
set DB2Z_JDBC=%START_DIR%\db2z
:after_db2z

set COGNOS_SDK=%START_DIR%\CognosSDK

rem Convert the current working directory
rem to a format that is valid for use in a
rem a file URL
set CUR_PATH=%cd%
set DRIVE=%cd:~0,1%
set SHORT_PATH=%~sp0%
set SHORT_PATH=%SHORT_PATH:\=/%
set PATH_URL=%DRIVE%%%3a%SHORT_PATH%

setlocal

rem common Liberty settings
call %cd%\liberty.env.bat

rem 32-bit/64-bit specific settings
call %cd%\liberty.64bit.env.bat

set JVM_ARGS=%JVM_ARGS% -Djava.awt.headless=true
set JVM_ARGS=%JVM_ARGS% -DSQLSERVER_JDBC_DRIVER_FILE="%SQLSERVER_JDBC_DRIVER_FILE%"
set JVM_ARGS=%JVM_ARGS% -DORACLE_JDBC_DRIVER_FILE="%ORACLE_JDBC_DRIVER_FILE%"
set JVM_ARGS=%JVM_ARGS% -DDB2I_JDBC="%DB2I_JDBC%"
set JVM_ARGS=%JVM_ARGS% -DDB2Z_JDBC="%DB2Z_JDBC%"
if "%DB2_ABSPATH%"=="" goto :after_db2
set JVM_ARGS=%JVM_ARGS% -DDB2_ABSPATH="%DB2_ABSPATH%/"
:after_db2
set JVM_ARGS=%JVM_ARGS% -Dorg.eclipse.emf.ecore.plugin.EcorePlugin.doNotLoadResourcesPlugin=true
set JVM_ARGS=%JVM_ARGS% -DJAZZ_HOME=file:///%PATH_URL%conf
set JVM_ARGS=%JVM_ARGS% -Dcom.ibm.team.repository.tempDir="%TEMP%"
set JVM_ARGS=%JVM_ARGS% -Djazz.connector.sslProtocol=SSL_TLS
set JVM_ARGS=%JVM_ARGS% -Djazz.connector.algorithm=IbmX509
set JVM_ARGS=%JVM_ARGS% -Xmx4G
set JVM_ARGS=%JVM_ARGS% -Xms4G
set JVM_ARGS=%JVM_ARGS% -Xmn512M
set JVM_ARGS=%JVM_ARGS% -Xgcpolicy:gencon
set JVM_ARGS=%JVM_ARGS% -Xcompressedrefs -Xgc:preferredHeapBase=0x100000000
set JVM_ARGS=%JVM_ARGS% -Dlog4j.configuration=file:///%PATH_URL%conf/startup_log4j.properties

rem Required for CLM Monitoring
rem set JVM_ARGS=%JVM_ARGS% -Dcom.sun.management.jmxremote=true
rem set JVM_ARGS=%JVM_ARGS% -Dcom.sun.management.jmxremote.port=1099
rem set JVM_ARGS=%JVM_ARGS% -Dcom.sun.management.jmxremote.ssl=false
rem set JVM_ARGS=%JVM_ARGS% -Dcom.sun.management.jmxremote.authenticate=false

rem Unset JAVA_HOME because we really want to use the JRE that is bundled.
set JAVA_HOME=

set JRE_HOME=%cd%\jre
set JVM_ARGS=%JVM_ARGS% -Duser.dir="%cd%"


call "%CLM_LIBERTY_HOME%"\bin\server.bat "%1" %CLM_LIBERTY_SERVER_NAME%

if "%1"=="create" (
  xcopy /y /s "%CLM_LIBERTY_SERVER_TEMPLATE%" "%cd%\liberty\servers\%CLM_LIBERTY_SERVER_NAME%"
)

endlocal

